@@ -1,7 +1,7 @@
 package Taskwarrior::Kusarigama::Hook;
 our $AUTHORITY = 'cpan:YANICK';
 # ABSTRACT: Entry-point for Kusarigama's hook scripts
-$Taskwarrior::Kusarigama::Hook::VERSION = '0.2.0';
+$Taskwarrior::Kusarigama::Hook::VERSION = '0.3.0';
 
 use 5.10.0;
 
@@ -127,7 +127,7 @@ Taskwarrior::Kusarigama::Hook - Entry-point for Kusarigama's hook scripts
 
 =head1 VERSION
 
-version 0.2.0
+version 0.3.0
 
 =head1 SYNOPSIS
 
@@ -136,7 +136,7 @@ version 0.2.0
     use Taskwarrior::Kusarigama::Hook;
 
     Taskwarrior::Kusarigama::Hook->new(
-        raw_args => @ARGV
+        raw_args => \@ARGV
     )->run_event( 'launch' );
 
 =head1 DESCRIPTION
