@@ -1,7 +1,7 @@
 package Taskwarrior::Kusarigama::Plugin::GitCommit;
 our $AUTHORITY = 'cpan:YANICK';
 # ABSTRACT: turns the task repo into a git repository
-$Taskwarrior::Kusarigama::Plugin::GitCommit::VERSION = '0.2.0';
+$Taskwarrior::Kusarigama::Plugin::GitCommit::VERSION = '0.3.0';
 
 use strict;
 use warnings;
@@ -12,7 +12,7 @@ use Git::Repository;
 
 use Moo;
 
-extends 'Taskwarrior::Kusarigama::Hook';
+extends 'Taskwarrior::Kusarigama::Plugin';
 
 with 'Taskwarrior::Kusarigama::Hook::OnExit';
 
@@ -35,7 +35,7 @@ sub on_exit {
     return unless $git->run( 'status', '--short' );
 
     $git->run( 'add', '.' );
-    $git->run( 'commit', '--message', 'on-exit saving' );
+    $git->run( 'commit', '--message', $self->args );
 
     $lock->release;
 };
@@ -54,7 +54,7 @@ Taskwarrior::Kusarigama::Plugin::GitCommit - turns the task repo into a git repo
 
 =head1 VERSION
 
-version 0.2.0
+version 0.3.0
 
 =head1 DESCRIPTION
 
