@@ -1,7 +1,7 @@
 package  Taskwarrior::Kusarigama::Wrapper;
 our $AUTHORITY = 'cpan:YANICK';
 # ABSTRACT: interface to the taskwarrior's 'task' command
-$Taskwarrior::Kusarigama::Wrapper::VERSION = '0.2.0';
+$Taskwarrior::Kusarigama::Wrapper::VERSION = '0.3.0';
 
 # TODO use Test::Pod::Snippet for that example ^^^
 
@@ -11,6 +11,8 @@ use 5.20.0;
 use IPC::Open3      qw();
 use Symbol;
 use  Taskwarrior::Kusarigama::Wrapper::Exception;
+use  Taskwarrior::Kusarigama::Task;
+
 use List::Util qw/ pairmap /;
 
 use Moo;
@@ -110,7 +112,9 @@ sub export {
     my( $self, @args ) = @_;
     require JSON;
 
-    return JSON::from_json( join '', $self->RUN( export => @args ) )->@*;
+    return map {
+        Taskwarrior::Kusarigama::Task->new( $self => $_ )
+    } JSON::from_json( join '', $self->RUN( export => @args ) )->@*;
 }
 
 sub AUTOLOAD {
@@ -138,7 +142,7 @@ Taskwarrior::Kusarigama::Wrapper - interface to the taskwarrior's 'task' command
 
 =head1 VERSION
 
-version 0.2.0
+version 0.3.0
 
 =head1 SYNOPSIS
 
@@ -169,8 +173,8 @@ For example:
 
 =head2 export
 
-As a convenience, C<export> returns the list of tasks exported (as hashref)
-instead than as raw text.
+As a convenience, C<export> returns the list of tasks exported (as 
+L<Taskwarrior::Kusarigama::Task> objects) instead than as raw text.
 
 =head1 AUTHOR
 
